@@ -5,16 +5,17 @@ def main():
     parser = argparse.ArgumentParser(prog ='pyinf', description ='easy file inserting') 
 
     #parser.add_argument('mode',help='(pypi) for pypi package setup', required = False)
-    parser.add_argument('--input', action='store', type=int, required=True)
-    parser.add_argument('--id', action='store', type=int)
+    parser.add_argument('mode', action='store', type=str, required=False)
 
     args = parser.parse_args()
 
+    print(parser.mode)
+
     if parser.mode == "pypi":
         print("demo")
     
-    f = open("main.py","w+")
+        f = open("main.py","w+")
 
-    f.write("""
-    print("PyInsertFile")
-    """)
+        f.write("""
+        print("PyInsertFile")
+        """)
